import { Component, ConcreteComponent, DefineComponent, HTMLAttributes, PropType } from 'vue';
import { ResponsiveValue, SystemProps, SystemStyleObject } from '@chakra-ui/styled-system';
import { CSSObject } from '@emotion/css';
import { DOMElements } from './system.utils';
import { ChakraProps, ComponentWithProps } from './system.types';
export interface BaseStyleResolverProps {
    as?: ChakraTagOrComponent;
    __css?: SystemStyleObject;
    sx?: SystemStyleObject;
    css?: CSSObject;
    noOfLines?: ResponsiveValue<number>;
    isTruncated?: boolean;
    apply?: ResponsiveValue<string>;
    componentName?: String;
    label?: string;
    baseStyle?: SystemStyleObject;
    /**
     * User provided styles from component/chakra API
     */
    styles?: SystemStyleObject;
    /**
     * This attribute/property is reserved for all TSX component definitions.
     * It is referenced by the chakra factiry function to
     * preserve the component's label class
     */
    __label?: string;
}
export interface StyleResolverProps extends BaseStyleResolverProps, SystemProps {
}
interface StyleResolverOptions extends StyleResolverProps {
    truncateStyle?: CSSObject;
    theme?: any;
}
declare const chakraProps: {
    as: PropType<ChakraTagOrComponent>;
    __css: PropType<import("@chakra-ui/styled-system").CSSObject | undefined>;
    sx: PropType<import("@chakra-ui/styled-system").CSSObject | undefined>;
    css: PropType<CSSObject | undefined>;
    noOfLines: PropType<ResponsiveValue<number> | undefined>;
    baseStyle: PropType<import("@chakra-ui/styled-system").CSSObject | undefined>;
    isTruncated: PropType<boolean | undefined>;
    layerStyle: PropType<ResponsiveValue<string & {}> | undefined>;
    textStyle: PropType<ResponsiveValue<string & {}> | undefined>;
    apply: PropType<ResponsiveValue<string> | undefined>;
    label: PropType<string | undefined>;
};
export declare type ChakraBaseComponentProps = typeof chakraProps;
export declare type ChakraTagOrComponent = DOMElements | Component | ConcreteComponent | string;
/**
 * Chakra factory serves as an object of chakra enabled HTML elements,
 * and also a function that can be used to enable custom component receive chakra's style props.
 * @param tag Tag or Component
 * @param options resolver options
 *
 * How does it work?
 *
 * 1. Components returned from the chakra factory can be styled after consuming them
 *    @example
 *    ```js
 *    const Form = chakra('form') // returns a VNode you can use in the template directly
 *    ```
 *
 * 2. Chakra components can directly be styled upon creation using the options object of type `StyleResolverProps`
 *    This resolves style object for component styles defined in the theme.
 *
 *    Styling components using the chakra factory function can be done using the following keys from the theme:
 *    - `baseStyle`
 *    - `layerStyle`
 *    - `textStyle`
 *
 *    @example
 *    ```js
 *    const MyCustomButton = chakra('button', {
 *     baseStyle: {
         bg: 'papayawhip,
         color: 'red.500,
         px: 4,
         py: 3
       }
 *    })
 *    ```
 *    ```html
 *    <my-custom-button>Hello Papaya Button</my-custom-button>
 *    ```
 *
 *    See more about the style resolution in the `resolveStyles` function.
 *
 * 3. Chakra components created and styled using the `chakra` factory can be overriden in the template by applying
 *    style properties directly
 *
 *    @example
 *    ```html
 *    <my-custom-button bg="blue.400">
 *      Papaya button goes blue
 *    </my-custom-button>
 *    ```
 */
export declare const chakra: IChakraFactory;
export declare const resolveStyles: (resolvers?: StyleResolverOptions) => CSSObject;
export declare type ChakraFactoryProps = ChakraProps & StyleResolverProps & HTMLAttributes & JSX.IntrinsicAttributes;
/**
 * @example
 * h(chakra(RouterLink, { to: 'https://vue.chakra-ui.com' }), {}, slots)
 */
declare type UserProvidedProps = {
    [key: string]: any;
};
declare type IChakraFactory = {
    [key in DOMElements]: DefineComponent | ComponentWithProps<ChakraFactoryProps>;
} & {
    (tag: ChakraTagOrComponent, options?: StyleResolverOptions & UserProvidedProps): DefineComponent | ComponentWithProps<ChakraFactoryProps>;
};
export {};
